%{?mingw_package_header}

Summary:       MinGW Windows Enchanting Spell Checking Library
Name:          mingw-enchant
Version:       1.6.1
Release:       %mkrel 2
Group:         Development/Other
License:       LGPLv2+
Source0:       https://github.com/AbiWord/enchant/releases/download/enchant-%(echo %{version} | sed "s/\\./-/g")/enchant-%{version}.tar.gz
URL:           http://www.abisource.com/

BuildRequires: mingw32-filesystem >= 95
BuildRequires: mingw32-gcc
BuildRequires: mingw32-gcc-c++
BuildRequires: mingw32-binutils
BuildRequires: mingw32-glib2
BuildRequires: mingw32-hunspell

BuildRequires: mingw64-filesystem >= 95
BuildRequires: mingw64-gcc
BuildRequires: mingw64-gcc-c++
BuildRequires: mingw64-binutils
BuildRequires: mingw64-glib2
BuildRequires: mingw64-hunspell

BuildRequires: m4

BuildArch:     noarch

# Fix a compile issue
Patch0:        enchant-mingw-compile-fix.patch

# Workaround for bug 12755 as upstream isn't alive any more
# Fixes a regression where relocatable support got broken
# http://bugzilla.abisource.com/show_bug.cgi?id=12755
Patch1:        enchant-remove-define-enchant-global-module-dir.patch

%description
A library that wraps other spell checking backends.

This is the MinGW build of enchant


# Win32
%package -n mingw32-enchant
Summary:       MinGW Windows Enchanting Spell Checking Library
Requires:      pkgconfig

%description -n mingw32-enchant
A library that wraps other spell checking backends.

This is the MinGW build of enchant

%package -n mingw32-enchant-static
Summary:       Static version of the MinGW Windows enchant library
Requires:      mingw32-enchant = %{version}-%{release}
Group:         Development/Other

%description -n mingw32-enchant-static
Static version of the MinGW Windows enchant spell checking library.

# Win64
%package -n mingw64-enchant
Summary:       MinGW Windows Enchanting Spell Checking Library
Requires:      pkgconfig

%description -n mingw64-enchant
A library that wraps other spell checking backends.

This is the MinGW build of enchant

%package -n mingw64-enchant-static
Summary:       Static version of the MinGW Windows enchant library
Requires:      mingw64-enchant = %{version}-%{release}
Group:         Development/Other

%description -n mingw64-enchant-static
Static version of the MinGW Windows enchant spell checking library.


%{?mingw_debug_package}


%prep
%setup -qn "enchant-%{version}"

%autopatch -p1


%build
%mingw_configure        \
    --disable-ispell    \
    --disable-hspell    \
    --disable-aspell    \
    --enable-static     \
    --enable-shared

# Work around a build issue
pushd build_win32/src
WINDRES=%{mingw32_windres} ../../compile-resource libenchant.rc enchant-win32res.o
popd
pushd build_win64/src
WINDRES=%{mingw64_windres} ../../compile-resource libenchant.rc enchant-win32res.o
popd

%mingw_make %{?_smp_mflags}


%install
%mingw_make DESTDIR=$RPM_BUILD_ROOT install

# Drop the man-pages
rm -rf $RPM_BUILD_ROOT%{mingw32_datadir}/man
rm -rf $RPM_BUILD_ROOT%{mingw64_datadir}/man

# Drop all .la files
find $RPM_BUILD_ROOT -name "*.la" -delete


# Win32
%files -n mingw32-enchant
%doc AUTHORS COPYING.LIB README
%{mingw32_bindir}/enchant-lsmod.exe
%{mingw32_bindir}/enchant.exe
%{mingw32_bindir}/libenchant.dll
%{mingw32_includedir}/enchant/
%dir %{mingw32_libdir}/enchant/
%{mingw32_libdir}/enchant/libenchant_myspell.dll
%{mingw32_libdir}/enchant/libenchant_myspell.dll.a
%{mingw32_libdir}/libenchant.dll.a
%{mingw32_libdir}/pkgconfig/enchant.pc
%{mingw32_datadir}/enchant/

%files -n mingw32-enchant-static
%{mingw32_libdir}/libenchant.a
%{mingw32_libdir}/enchant/libenchant_myspell.a

# Win64
%files -n mingw64-enchant
%doc AUTHORS COPYING.LIB README
%{mingw64_bindir}/enchant-lsmod.exe
%{mingw64_bindir}/enchant.exe
%{mingw64_bindir}/libenchant.dll
%{mingw64_includedir}/enchant/
%dir %{mingw64_libdir}/enchant/
%{mingw64_libdir}/enchant/libenchant_myspell.dll
%{mingw64_libdir}/enchant/libenchant_myspell.dll.a
%{mingw64_libdir}/libenchant.dll.a
%{mingw64_libdir}/pkgconfig/enchant.pc
%{mingw64_datadir}/enchant/

%files -n mingw64-enchant-static
%{mingw64_libdir}/libenchant.a
%{mingw64_libdir}/enchant/libenchant_myspell.a




%changelog
* Sat Sep 26 2020 tv <tv> 1.6.1-2.mga8
+ Revision: 1630231
- rebuild for new mingw stack

* Fri Feb 21 2020 daviddavid <daviddavid> 1.6.1-1.mga8
+ Revision: 1548823
- new version: 1.6.1

* Fri Feb 14 2020 umeabot <umeabot> 1.6.0-16.mga8
+ Revision: 1521520
- Mageia 8 Mass Rebuild

* Thu Dec 27 2018 daviddavid <daviddavid> 1.6.0-15.mga7
+ Revision: 1345241
- rebuild for new mingw-hunspell 1.7.0

* Thu Sep 20 2018 umeabot <umeabot> 1.6.0-14.mga7
+ Revision: 1279547
- Mageia 7 Mass Rebuild

* Mon Aug 06 2018 daviddavid <daviddavid> 1.6.0-13.mga7
+ Revision: 1248126
- rebuild for new mingw-hunspell 1.6.2

* Mon Feb 08 2016 umeabot <umeabot> 1.6.0-12.mga6
+ Revision: 942967
- Mageia 6 Mass Rebuild

* Wed Oct 15 2014 umeabot <umeabot> 1.6.0-11.mga5
+ Revision: 741957
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 1.6.0-10.mga5
+ Revision: 682426
- Mageia 5 Mass Rebuild

* Sun Sep 22 2013 neoclust <neoclust> 1.6.0-9.mga4
+ Revision: 483549
- imported package mingw-enchant

